Azure authentication providers
Structs
- Auth
Status - Authentication status
- AzCli
Auth - Azure CLI authentication provider
- EnvAuth
- Environment variable authentication provider
- Static
Token Auth - Static bearer token from the environment (
RIGG_ACCESS_TOKEN). Useful for CI systems that mint tokens out-of-band, and for tests.
Enums
- Auth
Error - Authentication errors
Traits
- Auth
Provider - Authentication provider trait
Functions
- get_
auth_ provider - Get the best available authentication provider for Search (backward compat)
- get_
auth_ provider_ for - Get the best available authentication provider for a specific service domain
- get_
cognitive_ services_ auth - Get the best available authentication provider for Azure Cognitive Services (OpenAI)