pub struct AzCliAuth { /* private fields */ }Expand description
Azure CLI authentication provider
Implementations
Sourceimpl AzCliAuth
impl AzCliAuth
Sourcepub fn for_search() -> Self
pub fn for_search() -> Self
Create an auth provider for Azure Search
Sourcepub fn for_foundry() -> Self
pub fn for_foundry() -> Self
Create an auth provider for Microsoft Foundry
Sourcepub fn for_cognitive_services() -> Self
pub fn for_cognitive_services() -> Self
Create an auth provider for Azure Cognitive Services (OpenAI)
Sourcepub fn for_cosmos() -> Self
pub fn for_cosmos() -> Self
Create an auth provider for Azure Cosmos DB
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new auth provider (defaults to Search scope for backward compatibility)
Sourcepub fn check_status() -> Result<AuthStatus, AuthError>
pub fn check_status() -> Result<AuthStatus, AuthError>
Check if Azure CLI is available and logged in
Sourcepub fn get_arm_token() -> Result<String, AuthError>
pub fn get_arm_token() -> Result<String, AuthError>
Get an access token for Azure Resource Manager (management.azure.com)