Module auth

Module auth 

Azure authentication providers

Structs

AuthStatus
Authentication status
AzCliAuth
Azure CLI authentication provider
EnvAuth
Environment variable authentication provider
StaticTokenAuth
Static bearer token from the environment (RIGG_ACCESS_TOKEN). Useful for CI systems that mint tokens out-of-band, and for tests.

Enums

AuthError
Authentication errors

Traits

AuthProvider
Authentication provider trait

Functions

get_auth_provider
Get the best available authentication provider for Search (backward compat)
get_auth_provider_for
Get the best available authentication provider for a specific service domain
get_cognitive_services_auth
Get the best available authentication provider for Azure Cognitive Services (OpenAI)